<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Afbeeldingen</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versie:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>afbeelding</translation>
    </message>
    <message>
        <source>images</source>
        <translation>afbeeldingen</translation>
    </message>
    <message>
        <source>album</source>
        <translation>album</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>albums</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Synchronisatie beheren</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Synchroniseren:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nieuw album</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Naamloos</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Recent geïmporteerd</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mijn favorieten</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Weet je zeker dat je dit album wilt verwijderen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mijn favorieten</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Tijdlijn</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Je kunt een te synchroniseren map toevoegen of afbeeldingen naar de tijdlijn verslepen</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Naamloos</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavoorstelling</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Afbeeldingen</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Afbeeldingen</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Weet je zeker dat je de afbeeldingen wilt toevoegen aan het album?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Synchroniseren en creëren</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Synchroniseren</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Weet je zeker dat je een map wilt toevoegen aan de synchronisatielijst en een gelijknamig album wilt creëren?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Geëxporteerd</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Exporteren mislukt</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Weet je zeker dat je de afbeeldingen wilt verplaatsen naar de prullenbak?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Afbeeldingsinformatie</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Dit bestand bevat meerdere pagina&apos;s. Gebruik Evince om alle pagina&apos;s te bekijken.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Volledig scherm</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavoorstelling</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Afdrukken</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopiëren naar klembord</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Verwijderen uit album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoriet</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Geen favoriet</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Instellen als bureaubladachtergrond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Afbeeldingsinformatie</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Je kunt een te synchroniseren map toevoegen of afbeeldingen naar de tijdlijn verslepen</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Toevoegen aan album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Toevoegen aan nieuw album</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Map openen</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Je bent niet gemachtigd om deze afbeeldingen te bekijken</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Gefotografeerd op</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Bewerkt op</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Afmetingen</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Bestandsgrootte</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Kleurruimte</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Belichtingsmodus</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Belichtingsprogramma</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Belichtingstijd</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flits</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Diafragma-opening</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Brandpuntsafstand</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Max. diafragma-opening</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Meetmethode</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Witbalans</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Flitscompensatie</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Cameramodel</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Lensmodel</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Niet aanpassen</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Pagina aanpassen aan afbeelding</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Afbeelding aanpassen aan pagina</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Aanpassen aan:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Millimeter</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centimeter</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Inches</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Afbeeldingspositie</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Aanpassing</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Afbeeldingsinstellingen</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Afbeeldingsinstellingen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Luxaflex</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Wisselaar</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Schuivend</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Ring</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Selecteer map</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Deze map is uitgeschakeld bij het synchroniseren</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Map toevoegen</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Mapsynchronisatie beheren</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>De mappenlijst is leeg</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Synchronisatie annuleren</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Het apparaat is losgekoppeld</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Deze map bestaat niet meer</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Bezig met berekenen...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Afbeelding bekijken</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Volledig scherm</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavoorstelling</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Diavoorstelling beëindigen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Verwijderen uit album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoriet</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Geen favoriet</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Instellen als bureaubladachtergrond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Afbeeldingsinformatie</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Vorige</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Vorig scherm</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Volgend scherm</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nieuw album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Sneltoetsen tonen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Voer een nieuwe sneltoets in</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Sneltoetsen</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Afbeelding bekijken</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Standaardwaarden herstellen</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Volledig scherm</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavoorstelling</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Diavoorstelling beëindigen</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Afdrukken</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Verwijderen uit album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoriet</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Geen favoriet</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Instellen als bureaubladachtergrond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Afbeeldingsinformatie</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nieuw album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Diavoorstelling beëindigen</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Pauzeren/Afspelen</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Diavoorstelling-instellingen</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Overgangseffect</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duur</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Overgangsduur</translation>
    </message>
    <message>
        <source>second</source>
        <translation>seconde</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Afbeeldingsbeheer</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mijn favorieten</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Grootte 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Aanpassen aan venster</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Geen favoriet</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoriet</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Geen afbeeldingsbestanden gevonden</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Afbeelding openen</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 afbeelding</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 afbeeldingen</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Synchronisatie beheren</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Synchroniseren:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Je kunt een te synchroniseren map toevoegen of afbeeldingen naar de tijdlijn verslepen</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Toevoegen aan album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Toevoegen aan nieuw album</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Volledig scherm</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavoorstelling</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Afdrukken</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopiëren naar klembord</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoriet</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Geen favoriet</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Instellen als bureaubladachtergrond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Afbeeldingsinformatie</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Diavoorstelling-instellingen</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Effect</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duur</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Sneltoetsen</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mijn favorieten</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Recent geïmporteerd</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Nieuw album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Deepin Afbeeldingen is een moderne en gepolijste afbeeldingenbeheerder.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Je kunt afbeeldingen bekijken en beheren en simpele bewerkingen toepassen.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Donker thema</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Deepin Afbeeldingen is een moderne en gepolijste afbeeldingenbeheerder, met vloeiende prestaties.</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Tijdlijn</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Toevoegen aan album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Toevoegen aan nieuw album</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Volledig scherm sluiten</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Volledig scherm</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavoorstelling</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Afdrukken</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopiëren naar klembord</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Verwijderen uit album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoriet</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Geen favoriet</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Navigatievenster tonen</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Navigatievenster verbergen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Instellen als bureaubladachtergrond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Afbeeldingsinformatie</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Afbeelding openen</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Alle afbeeldingen</translation>
    </message>
</context>
</TS>